@@ -12,9 +12,10 @@
 
 ;; GC debug flags.
 #+sbcl
-(setf (extern-alien "pre_verify_gen_0" char) 1
+(setf (extern-alien "pre_verify_gen_0" int)  1
       (extern-alien "verify_gens" char)      0
-      (extern-alien "gencgc_verbose" char)   1)
+      (extern-alien "gencgc_verbose" int)    1)
+#+sbcl (gc)
 
 (let ((asdf:*user-cache* (uiop:getenv "AUTOPKGTEST_TMP"))) ; Store FASL in some temporary dir
   (asdf:load-system "ironclad/tests")
